==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/base/ibgextensionwindowsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Toolkit-independent base for the extension window
//

#ifndef IBGEXTENSIONWINDOWSUBJECT_H
#define IBGEXTENSIONWINDOWSUBJECT_H


#include "ibgwindowsubject.h"


class iggAbstractExtension;
class iggExtensionWindow;


class ibgExtensionWindowSubject : public ibgWindowSubject
{

public:

	virtual void Show(bool s);

	virtual void AddExtension(iggAbstractExtension *ext) = 0;
	virtual void SetPadding(bool s) = 0;

protected:

	ibgExtensionWindowSubject(iggExtensionWindow *ew, bool single);
	virtual ~ibgExtensionWindowSubject();

	iggExtensionWindow *mExtensionWindow;
};

#endif  // IBGEXTENSIONWINDOWSUBJECT_H

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/shells/base/ibgextensionwindowsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Toolkit-independent base for the extension window
//

#ifndef IBGEXTENSIONWINDOWSUBJECT_H
#define IBGEXTENSIONWINDOWSUBJECT_H


#include "ibgwindowsubject.h"


class iggExtensionWindow;
class iggFrame;


class ibgExtensionWindowSubject : public ibgWindowSubject
{

public:

	virtual void Show(bool s);
	virtual void AttachPanels(iggFrame *main, iggFrame *bottom, iggFrame *left) = 0;

protected:

	ibgExtensionWindowSubject(iggExtensionWindow *ew);
	virtual ~ibgExtensionWindowSubject();

	iggExtensionWindow *mExtensionWindow;
};

#endif  // IBGEXTENSIONWINDOWSUBJECT_H
